@@ -1,7 +1,5 @@
 #!/bin/sh
 
-echo "Running qmake..."
-
 if test -f qtdir ; then
   QTDIR=`cat qtdir`
   export QTDIR
@@ -9,6 +7,8 @@ fi
 
 test -z "${QMAKE}" && QMAKE="qmake"
 
+echo "Running qmake: ${QMAKE}"
+
 ${QMAKE}
 
 ${QMAKE} -o src/Makefile        src/src.pro
