@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: DialogFactory.cpp,v 1.8.4.3 2005/10/27 04:48:12 vkurland Exp $
+  $Id: DialogFactory.cpp,v 1.14 2006/02/16 07:35:17 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -35,6 +35,8 @@
 #include "AddressRangeDialog.h"
 #include "IPv4Dialog.h"
 #include "PhysicalAddressDialog.h"
+#include "DNSNameDialog.h"
+#include "AddressTableDialog.h"
 #include "NetworkDialog.h"
 #include "CustomServiceDialog.h"
 #include "ICMPServiceDialog.h"
@@ -46,6 +48,7 @@
 #include "FirewallDialog.h"
 #include "InterfaceDialog.h"
 #include "TimeDialog.h"
+#include "TagServiceDialog.h"
 
 #include "iptAdvancedDialog.h"
 #include "ipfAdvancedDialog.h"
@@ -62,6 +65,8 @@
 #include "macosxAdvancedDialog.h"
 
 #include "RuleOptionsDialog.h"
+#include "RoutingRuleOptionsDialog.h"
+#include "NATRuleOptionsDialog.h"
 
 
 #include "fwbuilder/Library.h"
@@ -69,6 +74,8 @@
 #include "fwbuilder/Host.h"
 #include "fwbuilder/Network.h"
 #include "fwbuilder/IPv4.h"
+#include "fwbuilder/DNSName.h"
+#include "fwbuilder/AddressTable.h"
 #include "fwbuilder/AddressRange.h"
 #include "fwbuilder/ObjectGroup.h"
 #include "fwbuilder/Interface.h"
@@ -82,6 +89,7 @@
 #include "fwbuilder/IntervalGroup.h"
 #include "fwbuilder/Rule.h"
 #include "fwbuilder/Resources.h"
+#include "fwbuilder/TagService.h"
 
 #include <iostream>
 
@@ -97,6 +105,10 @@ QWidget *DialogFactory::createDialog(QWidget *parent,const QString &objType)
 
     if (objType==physAddress::TYPENAME)   return new PhysicalAddressDialog(parent);
 
+    if (objType==DNSName::TYPENAME)       return new DNSNameDialog(parent);
+
+    if (objType==AddressTable::TYPENAME)  return new AddressTableDialog(parent);
+
     if (objType==AddressRange::TYPENAME)  return new AddressRangeDialog(parent);
 
     if (objType==Firewall::TYPENAME)      return new FirewallDialog(parent);
@@ -120,14 +132,17 @@ QWidget *DialogFactory::createDialog(QWidget *parent,const QString &objType)
     if (objType==ObjectGroup::TYPENAME)   return new GroupObjectDialog(parent);
 
     if (objType==ServiceGroup::TYPENAME)  return new GroupObjectDialog(parent);
+    
+    if (objType==TagService::TYPENAME)          return new TagServiceDialog(parent);
 
     if (objType==IntervalGroup::TYPENAME) return new GroupObjectDialog(parent);
 
     if (objType==Interval::TYPENAME)      return new TimeDialog(parent);
 
+    if (objType==RoutingRule::TYPENAME)   return new RoutingRuleOptionsDialog(parent);
     if (objType==Rule::TYPENAME)          return new RuleOptionsDialog(parent);
     if (objType==PolicyRule::TYPENAME)    return new RuleOptionsDialog(parent);
-    if (objType==NATRule::TYPENAME)       return new RuleOptionsDialog(parent);
+    if (objType==NATRule::TYPENAME)       return new NATRuleOptionsDialog(parent);
 
     return NULL;
 }
