@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: DiscoveryDruid.cpp,v 1.26 2006/09/08 03:01:46 vkurland Exp $
+  $Id: DiscoveryDruid.cpp,v 1.27 2006/09/18 06:59:52 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -1730,7 +1730,7 @@ void DiscoveryDruid::checkSNMPCommunity()
     }
     else
     {
-        snmpcommunity_message->setText(tr(""));
+        snmpcommunity_message->setText("");
         setNextEnabled(currentPage(),true);
     }
 }
