@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWBSettings.h,v 1.18 2005/01/22 01:58:00 vkurland Exp $
+  $Id: FWBSettings.h,v 1.20 2006/06/26 03:21:00 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -40,6 +40,7 @@ class QWidget;
 #define LoadStandardObjects 0
 #define LoadLastEditedFile  1
     
+#define SETTINGS_PATH_PREFIX  "/FirewallBuilder2_1"
 
 class FWBSettings : public QSettings {
 
@@ -128,9 +129,6 @@ class FWBSettings : public QSettings {
     QString getLabelText(enum LabelColors c);
     void    setLabelText(enum LabelColors c, const QString &s);
 
-    QString getSCPPath();
-    void    setSCPPath(const QString &path);
-    
     QString getSSHPath();
     void    setSSHPath(const QString &path);
 
