@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWBTree.cpp,v 1.26 2006/09/09 05:04:58 vkurland Exp $
+  $Id: FWBTree.cpp,v 1.27 2007/04/24 05:00:47 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -312,7 +312,8 @@ FWBTree::FWBTree()
  */
 bool FWBTree::isSystem(FWObject *obj)
 {
-    if (Library::isA(obj))   return (obj->getId()==STANDARD_LIB);
+    if (Library::isA(obj))
+        return (obj->getId()==STANDARD_LIB || obj->getId()==DELETED_LIB);
 
     if (FWObjectDatabase::isA(obj)) return true;
 
