@@ -2,11 +2,11 @@
 
                           Firewall Builder
 
-                 Copyright (C) 2000-2004 NetCitadel, LLC
+                 Copyright (C) 2000-2006 NetCitadel, LLC
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: FWObjectClipboard.h,v 1.5 2004/12/12 08:38:29 vkurland Exp $
+  $Id: FWObjectClipboard.h,v 1.6 2006/09/15 05:48:20 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -30,12 +30,13 @@
 #define _FWOBJECT_CLIPBOARD_H
 
 #include <vector>
+#include <string>
 
 class libfwbuilder::FWObject;
 
 class FWObjectClipboard  {
 
-    std::vector<libfwbuilder::FWObject*> objects;
+    std::vector<std::string> ids;
 
 public:
 
@@ -57,11 +58,11 @@ public:
      */
     void clear();
 
-    std::vector<libfwbuilder::FWObject*>::iterator begin() { return objects.begin(); }
-    std::vector<libfwbuilder::FWObject*>::iterator end() { return objects.end(); }
-    std::vector<libfwbuilder::FWObject*>::reverse_iterator rbegin() { return objects.rbegin(); }
-    std::vector<libfwbuilder::FWObject*>::reverse_iterator rend() { return objects.rend(); }
-    int size() { return objects.size(); }
+    std::vector<std::string>::iterator begin() { return ids.begin(); }
+    std::vector<std::string>::iterator end() { return ids.end(); }
+    std::vector<std::string>::reverse_iterator rbegin() { return ids.rbegin(); }
+    std::vector<std::string>::reverse_iterator rend() { return ids.rend(); }
+    int size() { return ids.size(); }
     
     static FWObjectClipboard  *obj_clipboard;
 };
