@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWObjectPropertiesFactory.cpp,v 1.50 2006/10/24 03:43:25 vkurland Exp $
+  $Id: FWObjectPropertiesFactory.cpp,v 1.51 2007/02/04 03:58:59 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -31,6 +31,7 @@
 #include <qobject.h>
 #include <qtextstream.h>
 #include <qdatetime.h>
+#include <qregexp.h>
 
 #include "FWObjectPropertiesFactory.h"
 #include "platforms.h"
@@ -203,11 +204,28 @@ QString FWObjectPropertiesFactory::getObjectProperties(FWObject *obj)
 }
 
 
+QString FWObjectPropertiesFactory::stripHTML(const QString &str)
+{
+    // note that str may contain multiple lines
+    // separated by <br> and/or '\n'
+
+    QRegExp htmltag1 = QRegExp("<[^>]+>");
+    QRegExp htmltag2 = QRegExp("</[^>]+>");
+    QRegExp htmltd   = QRegExp("</td><td>");
+
+    QString res = str;
+    res = res.replace(htmltd,": ");
+    res = res.remove(htmltag1);
+    res = res.remove(htmltag2);
+    return res;
+}
+
 
 QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
                                                                bool showPath,
                                                                bool tooltip,
-                                                               bool accentName)
+                                                               bool accentName,
+                                                               bool richText)
 {
     QString str;
 
@@ -240,18 +258,18 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
 
         if (IPv4::isA(obj))
         {
-            if (showPath && !tooltip) str += path + "<br>\n";
+            if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
             str +=  Address::cast(obj)->getAddress().toString().c_str();
             str += "/";
             str += Address::cast(obj)->getNetmask().toString().c_str();
 
         } else if (physAddress::isA(obj))
         {
-            if (showPath && !tooltip) str += path + "<br>\n";
+            if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
             str += physAddress::cast(obj)->getPhysAddress().c_str();
         } else if (DNSName::isA(obj))
         {
-            if (showPath && !tooltip) str += path + "<br>\n";
+            if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
             str += QObject::tr("<b>DNS record:</b>");
             str += MultiAddress::cast(obj)->getSourceName().c_str();
             str += "<br>\n";
@@ -259,7 +277,7 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
 
         } else if (AddressTable::isA(obj))
         {
-            if (showPath && !tooltip) str += path + "<br>\n";
+            if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
             str += QObject::tr("<b>Table file:</b>");
             str += MultiAddress::cast(obj)->getSourceName().c_str();
             str += "<br>\n";
@@ -267,14 +285,14 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
             
         } else if (AddressRange::isA(obj))
         {
-            if (showPath && !tooltip) str += path + "<br>\n";
+            if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
             AddressRange *ar=AddressRange::cast(obj);
             str += ar->getRangeStart().toString().c_str();
             str += " - ";
             str += ar->getRangeEnd().toString().c_str();
         } else if (Host::isA(obj))
         {
-            if (showPath && !tooltip) str += path + "<br>\n";
+            if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
 
             str +=  Address::cast(obj)->getAddress().toString().c_str() ;
 
@@ -288,7 +306,7 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
 
         } else if (Network::isA(obj))
         {
-            if (showPath && !tooltip) str += path + "<br>\n";
+            if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
             Network *n=Network::cast(obj);
             str += n->getAddress().toString().c_str();
             str += "/";
@@ -296,7 +314,7 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
 
         } else if (Group::cast(obj)!=NULL)   // just any group
         {
-            if (showPath && !tooltip) str += path + "<br>\n";
+            if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
             Group *g=Group::cast(obj);
             str += QObject::tr("%1 objects<br>\n").arg(g->size());
             int n = 0;
@@ -344,7 +362,7 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
             
                
 
-            if (showPath && !tooltip) str += path + "<br>\n";
+            if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
             str += "<table cellspacing=\"0\" cellpadding=\"0\">";
             str += QString("<tr><td>Platform:</td><td>") +
                 platform + "</td></tr>\n";
@@ -382,7 +400,7 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
             
             if (q!="") str += " (" + q + ")";
             str += "<br>\n";
-            if (showPath && !tooltip) str += path + "<br>\n";
+            if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
 
             physAddress *paddr=(Interface::cast(obj))->getPhysicalAddress();
             if (paddr!=NULL) 
@@ -395,7 +413,7 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
         } else if (CustomService::isA(obj))
         {
 
-            if (showPath && !tooltip) str += path + "<br>\n";
+            if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
 
             CustomService *s = dynamic_cast<CustomService*>(obj);
             bool first=true;
@@ -419,12 +437,12 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
 
         } else if (IPService::isA(obj))
         {
-            if (showPath && !tooltip) str += path + "<br>\n";
+            if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
             str += QObject::tr("protocol ") + obj->getStr("protocol_num").c_str();
 
         } else if (ICMPService::isA(obj))
         {
-            if (showPath && !tooltip) str += path + "<br>\n";
+            if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
             str += QObject::tr("type: ") + obj->getStr("type").c_str()
                 + "  "
                 + QObject::tr("code: ") + obj->getStr("code").c_str();
@@ -438,11 +456,11 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
             dps=obj->getInt("dst_range_start");
             dpe=obj->getInt("dst_range_end");
 
-            if (showPath && !tooltip) str += path + "<br>\n";
+            if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
             str += "<table cellspacing=\"0\" cellpadding=\"0\">";
-            str += QString("<tr><td>source port range</td><td>%1:%2</td></tr>")
+            str += QString("<tr><td>source port range</td><td>%1:%2</td></tr>\n")
                 .arg(sps).arg(spe);
-            str += QString("<tr><td>destination port range</td><td>%1:%2</td></tr>")
+            str += QString("<tr><td>destination port range</td><td>%1:%2</td></tr>\n")
                 .arg(dps).arg(dpe);
             str += "</table>";
         } else if (TagService::isA(obj)) 
@@ -457,7 +475,9 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
         cerr << ex.toString() << endl;
     }
 
-    return str;
+    if (richText) return str;
+
+    return FWObjectPropertiesFactory::stripHTML(str);
 }
 
 /*
