@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindow.cpp,v 1.215 2007/02/04 03:58:59 vkurland Exp $
+  $Id: FWWindow.cpp,v 1.217 2007/02/17 19:13:54 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -1435,7 +1435,7 @@ void FWWindow::fileCompare()
     try
     {
         db1 = new FWObjectDatabase();
-        db1->load(fname1,  &upgrade_predicate,  librespath);
+        db1->load(fname1.latin1(),  &upgrade_predicate,  librespath);
 
         dobj = db1->findInIndex(FWObjectDatabase::getDeletedObjectsId());
         if (dobj) db1->remove(dobj, false);
@@ -1453,7 +1453,7 @@ void FWWindow::fileCompare()
     try
     {
         db2 = new FWObjectDatabase();
-        db2->load(fname2,  &upgrade_predicate,  librespath);
+        db2->load(fname2.latin1(),  &upgrade_predicate,  librespath);
 
         dobj = db2->findInIndex(FWObjectDatabase::getDeletedObjectsId());
         if (dobj) db2->remove(dobj, false);
@@ -1485,7 +1485,7 @@ void FWWindow::fileCompare()
         str << cod.getNumberOfConflicts();
 
         QMessageBox mb( "Firewall Builder",
-                        tr("Total number of conflicting objects: %1.\nDo you want to generate report?").arg(str.str()),
+                        tr("Total number of conflicting objects: %1.\nDo you want to generate report?").arg(str.str().c_str()),
                         QMessageBox::Information,
                         QMessageBox::Yes | QMessageBox::Default,
                         QMessageBox::No,
@@ -1987,7 +1987,7 @@ void FWWindow::setPolicyBranchTabName(RuleSet *subset)
     assert(rsv);
     FWOptions *ropt = rule->getOptionsObject();
     QString branchName = ropt->getStr("branch_name").c_str();
-    ruleSets->changeTab(rsv, tr("Policy/%1").arg(branchName) );
+    ruleSets->changeTab(rsv, tr("%1").arg(branchName) );
 }
 
 void FWWindow::addPolicyBranchTab(RuleSet *subset)
