@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FirewallDialog.cpp,v 1.41 2006/12/01 05:57:39 vkurland Exp $
+  $Id: FirewallDialog.cpp,v 1.42 2007/04/14 00:18:43 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -205,6 +205,8 @@ void FirewallDialog::changed()
 void FirewallDialog::validate(bool *res)
 {
     *res=true;
+    if (!isTreeReadWrite(this,obj)) { *res=false; return; }
+    if (!validateName(this,obj,obj_name->text())) { *res=false; return; }
 }
 
 void FirewallDialog::isChanged(bool *res)
@@ -221,13 +223,6 @@ void FirewallDialog::libChanged()
 
 void FirewallDialog::applyChanges()
 {
-    if (!isTreeReadWrite(this,obj)) return;
-    if (!validateName(this,obj,obj_name->text())) return;
-
-    bool res=true;
-    validate( &res );
-    if (!res) return;
-
     Firewall *s = dynamic_cast<Firewall*>(obj);
     Management *mgmt=s->getManagementObject();
     assert(mgmt!=NULL);
