@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: GroupObjectDialog.cpp,v 1.57 2007/01/08 03:24:48 vkurland Exp $
+  $Id: GroupObjectDialog.cpp,v 1.58 2007/04/14 00:18:43 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -469,6 +469,8 @@ void GroupObjectDialog::changed()
 void GroupObjectDialog::validate(bool *res)
 {
     *res=true;
+    if (!isTreeReadWrite(this,obj)) { *res=false; return; }
+    if (!validateName(this,obj,obj_name->text())) { *res=false; return; }
 }
 
 void GroupObjectDialog::isChanged(bool *res)
@@ -486,9 +488,6 @@ void GroupObjectDialog::applyChanges()
     if (fwbdebug)
         qDebug("GroupObjectDialog::applyChanges");
 
-    if (!isTreeReadWrite(this,obj)) return;
-    if (!validateName(this,obj,obj_name->text())) return;
-
     string oldname=obj->getName();
     obj->setName( string(obj_name->text().utf8()) );
     obj->setComment( string(comment->text().utf8()) );
