@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectManipulator.cpp,v 1.159 2006/10/22 18:20:04 vkurland Exp $
+  $Id: ObjectManipulator.cpp,v 1.161 2007/01/10 06:28:51 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -130,7 +130,7 @@ void ObjToolTip::maybeTip(const QPoint &p)
     {
         QListViewItem *itm = otv->itemAt( p );
         if (itm==NULL) return;
-        ObjectTreeViewItem *otvi=dynamic_cast<ObjectTreeViewItem*>(itm);
+        ObjectTreeViewItem *otvi = dynamic_cast<ObjectTreeViewItem*>(itm);
         assert(otvi);
         FWObject *obj=otvi->getFWObject();
         QRect     cr =otv->itemRect(itm);
@@ -147,7 +147,7 @@ ObjectManipulator::ObjectManipulator( QWidget *parent ) :
     treeHeight   = -1;
     currentObj   = NULL;
     active       = false;
-    currentTreeView=NULL;
+    current_tree_view=NULL;
 
 //    setFocusPolicy( QWidget::StrongFocus  );
 
@@ -782,6 +782,22 @@ void ObjectManipulator::removeLib(int id)
     }
 }
 
+void ObjectManipulator::switchingTrees(QWidget* w)
+{
+    ObjectTreeView *new_otv = dynamic_cast<ObjectTreeView*>(w);
+
+    if (fwbdebug)
+        qDebug("ObjectManipulator::switchingTrees  current_otv=%p  new_otv=%p",
+               (void*)(current_tree_view),(void*)(new_otv));
+
+    assert(new_otv);
+
+    if (current_tree_view!=NULL) current_tree_view->becomingHidden();
+    new_otv->becomingVisible();
+    current_tree_view = new_otv;
+
+}
+
 void ObjectManipulator::makeNameUnique(FWObject* parent,FWObject* obj)
 {
     int      suffix=1;
@@ -1822,8 +1838,8 @@ void ObjectManipulator::delObj(FWObject *obj,bool openobj)
     try
     {
         if (fwbdebug)
-            qDebug("ObjectManipulator::delObj  delete obj %p %s",
-                   obj,obj->getName().c_str());
+            qDebug("ObjectManipulator::delObj  delete obj %p %s openobj=%d",
+                   obj,obj->getName().c_str(),openobj);
 
         FWObject *parent=obj->getParent();
         FWObject *delObjLib = mw->db()->findInIndex( DELETED_LIB );
@@ -1866,7 +1882,7 @@ void ObjectManipulator::delObj(FWObject *obj,bool openobj)
                 mw->deleteFirewall( *i );
         }
 
-        if (isfw) mw->deleteFirewall(obj);
+        if (isfw && !isDelObj) mw->deleteFirewall(obj);
 
 
 //        removeObjectFromTreeView(obj);
@@ -1901,7 +1917,7 @@ void ObjectManipulator::delObj(FWObject *obj,bool openobj)
 
         if (openobj)
         {
-            if (isfw)
+            if (isfw && !isDelObj)
             {
                 std::list<Firewall*> fwlist;
                 findAllFirewalls(fwlist);
@@ -2161,8 +2177,15 @@ void ObjectManipulator::openObject(FWObject *obj)
 
 void ObjectManipulator::showObjectInTree(ObjectTreeViewItem *otvi)
 {
+    if (fwbdebug) qDebug("ObjectManipulator::showObjectInTree");
     if (otvi==NULL) return;
-    widgetStack->raiseWidget( currentTreeView=otvi->getTree() );
+
+    ObjectTreeView* otv = otvi->getTree();
+
+    if (fwbdebug) qDebug("ObjectManipulator::showObjectInTree  current_tree_view=%p  new_otv=%p",current_tree_view,otv);
+
+    widgetStack->raiseWidget( otv );
+
     otvi->getTree()->clearSelection();
     otvi->getTree()->ensureItemVisible( otvi );
     otvi->getTree()->setCurrentItem( otvi );
@@ -2242,7 +2265,7 @@ FWObject*  ObjectManipulator::getCurrentLib()
 
 ObjectTreeView* ObjectManipulator::getCurrentObjectTree()
 {
-    return currentTreeView;
+    return current_tree_view;
 }
 
 void ObjectManipulator::openLib(FWObject *obj)
