@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectTreeView.cpp,v 1.39 2007/01/08 03:24:48 vkurland Exp $
+  $Id: ObjectTreeView.cpp,v 1.42 2007/03/22 15:09:02 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -205,18 +205,25 @@ bool ObjectTreeView::isUnlockable()
 
 void ObjectTreeView::focusInEvent(QFocusEvent* ev)
 {
+    if (fwbdebug) qDebug("ObjectTreeView::focusInEvent 1");
     QListView::focusInEvent(ev);
-    repaintItem(currentItem());
+    QListViewItem *ci = currentItem();
+    if (ci) repaintItem(ci);
+    if (fwbdebug) qDebug("ObjectTreeView::focusInEvent 2");
 }
 
 void ObjectTreeView::focusOutEvent(QFocusEvent* ev)
 {
+    if (fwbdebug) qDebug("ObjectTreeView::focusOutEvent 1");
     QListView::focusOutEvent(ev);
-    repaintItem(currentItem());
+    QListViewItem *ci = currentItem();
+    if (ci) repaintItem(ci);
+    if (fwbdebug) qDebug("ObjectTreeView::focusOutEvent 2");
 }
 
 void ObjectTreeView::updateTreeItems()
 {
+    if (fwbdebug) qDebug("ObjectTreeView::updateTreeItems 1");
     QListViewItemIterator it(this);
     QListViewItem *itm;
     ObjectTreeViewItem *otvi;
@@ -262,6 +269,7 @@ void ObjectTreeView::updateTreeItems()
         ++it;
     }
     triggerUpdate ();  
+    if (fwbdebug) qDebug("ObjectTreeView::updateTreeItems 2");
 }
 
 /*
