@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: RuleOptionsDialog.cpp,v 1.21 2006/09/17 18:58:12 vkurland Exp $
+  $Id: RuleOptionsDialog.cpp,v 1.22 2007/04/14 01:48:51 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -123,6 +123,11 @@ void RuleOptionsDialog::loadFWObject(FWObject *o)
         data.registerOption( ipt_hashlimit_burst      , ropt,  "hashlimit_burst" );
         data.registerOption( ipt_hashlimit_mode       , ropt,  "hashlimit_mode" );
         data.registerOption( ipt_hashlimit_dstlimit   , ropt,  "hashlimit_dstlimit");
+        data.registerOption( ipt_hashlimit_name       , ropt,  "hashlimit_name");
+        data.registerOption( ipt_hashlimit_size       , ropt,  "hashlimit_size");
+        data.registerOption( ipt_hashlimit_max        , ropt,  "hashlimit_max");
+        data.registerOption( ipt_hashlimit_expire     , ropt,  "hashlimit_expire");
+        data.registerOption( ipt_hashlimit_gcinterval , ropt,  "hashlimit_gcinterval");
 
         data.registerOption( ipt_assumeFwIsPartOfAny  , ropt,  "firewall_is_part_of_any_and_networks" );
         data.registerOption( ipt_stateless            , ropt,  "stateless" );
