@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHPIX.h,v 1.5 2006/04/24 06:23:58 vkurland Exp $
+  $Id: SSHPIX.h,v 1.6 2006/09/17 05:15:50 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -55,7 +55,8 @@ class SSHPIX : public SSHSession {
     
 public:
     
-    SSHPIX(const QString &host,
+    SSHPIX(QWidget *parent,
+           const QString &host,
            const QStringList &args,
            const QString &pwd,
            const QString &epwd,
