@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHUnx.h,v 1.4 2006/09/17 05:15:50 vkurland Exp $
+  $Id: SSHUnx.h,v 1.5 2007/04/25 05:34:21 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -40,6 +40,9 @@ class SSHUnx : public SSHSession {
 
     Q_OBJECT
 
+    QStringList iptables_errors;
+
+        
 public:
     
     SSHUnx(QWidget *parent,
@@ -52,6 +55,7 @@ public:
 
     virtual void stateMachine();
 
+    bool checkForErrors(QStringList *errptr);
 };
 
 #endif
