@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: TCPServiceDialog.cpp,v 1.23 2006/05/13 06:53:05 vkurland Exp $
+  $Id: TCPServiceDialog.cpp,v 1.24 2007/04/14 00:18:43 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -41,6 +41,7 @@
 #include <qtextedit.h>
 #include <qcombobox.h>
 #include <qpushbutton.h>
+#include <qmessagebox.h>
 
 using namespace std;
 using namespace libfwbuilder;
@@ -148,7 +149,35 @@ void TCPServiceDialog::changed()
 
 void TCPServiceDialog::validate(bool *res)
 {
+    if (fwbdebug) qDebug("TCPServiceDialog::validate");
+
     *res=true;
+
+    if (!isTreeReadWrite(this,obj)) { *res=false; return; }
+    if (!validateName(this,obj,obj_name->text())) { *res=false; return; }
+
+    // check port ranges (bug #1695481, range start must be <= range end)
+    int sps = ss->value();
+    int spe = se->value();
+    int dps = ds->value();
+    int dpe = de->value();
+
+    if (sps > spe)
+    {
+        QMessageBox::warning(this, "Firewall Builder",
+          QObject::tr("Invalid range defined for the source port."),
+          QObject::tr("&Continue editing"), NULL, NULL, 0, 2 );
+        *res = false;
+        return;
+    }
+    if (dps > dpe)
+    {
+        QMessageBox::warning(this, "Firewall Builder",
+          QObject::tr("Invalid range defined for the destination port."),
+          QObject::tr("&Continue editing"), NULL, NULL, 0, 2 );
+        *res = false;
+        return;
+    }
 }
 
 void TCPServiceDialog::isChanged(bool *res)
@@ -163,9 +192,6 @@ void TCPServiceDialog::libChanged()
 
 void TCPServiceDialog::applyChanges()
 {
-    if (!isTreeReadWrite(this,obj)) return;
-    if (!validateName(this,obj,obj_name->text())) return;
-
     string oldname=obj->getName();
     obj->setName( string(obj_name->text().utf8()) );
     obj->setComment( string(comment->text().utf8()) );
