@@ -2,11 +2,11 @@
 
                           Firewall Builder
 
-                 Copyright (C) 2003 NetCitadel, LLC
+                 Copyright (C) 2006 NetCitadel, LLC
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: instBatchOptionsDialog.cpp,v 1.3 2006/08/28 06:03:10 vkurland Exp $
+  $Id: instBatchOptionsDialog.cpp,v 1.4 2007/01/06 08:24:57 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -31,10 +31,6 @@
 
 #include "instBatchOptionsDialog.h"
 
-#include "fwbuilder/Library.h"
-#include "fwbuilder/FWException.h"
-#include "fwbuilder/Firewall.h"
-
 #include <qstring.h>
 #include <qlineedit.h>
 #include <qlabel.h>
@@ -44,7 +40,7 @@
 using namespace std;
 using namespace libfwbuilder;
 
-instBatchOptionsDialog::instBatchOptionsDialog(QWidget *parent) : instOptionsDialog_q(parent)
+instBatchOptionsDialog::instBatchOptionsDialog(QWidget *parent) : instOptionsDialog(parent)
 {
     dialogTitleLine->setText(QString("<p align=\"center\"><b><font size=\"+2\">")+
                              tr("Batch install options")+
@@ -55,24 +51,3 @@ instBatchOptionsDialog::instBatchOptionsDialog(QWidget *parent) : instOptionsDia
     
 }
 
-void instBatchOptionsDialog::applyChanges()
-{
-    hide();
-}
-
-void instBatchOptionsDialog::discardChanges()
-{
-    hide();
-}
-
-QString instBatchOptionsDialog::getUName() { return uname->text(); }
-QString instBatchOptionsDialog::getPWD()   { return pwd->text();   }
-QString instBatchOptionsDialog::getEPWD()  { return epwd->text();  }
-
-void instBatchOptionsDialog::closeEvent(QCloseEvent *e)
-{
-    if (fwbdebug)
-        qDebug("instBatchOptionsDialog::closeEvent  got close event: %p",e);
-    hide();
-}
-
