@@ -2,11 +2,11 @@
 
                           Firewall Builder
 
-                 Copyright (C) 2003 NetCitadel, LLC
+                 Copyright (C) 2006 NetCitadel, LLC
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: instBatchOptionsDialog.h,v 1.1 2006/04/13 16:18:52 vkurland Exp $
+  $Id: instBatchOptionsDialog.h,v 1.2 2007/01/06 08:24:57 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,37 +28,16 @@
 #define __INSTBATCHOPTIONSDIALOG_H_
 
 #include "config.h"
-#include <instoptionsdialog_q.h>
+#include <instOptionsDialog.h>
 
-#include "fwbuilder/FWObject.h"
-#include "fwbuilder/Resources.h"
-
-
-
-class instBatchOptionsDialog : public instOptionsDialog_q
+class instBatchOptionsDialog : public instOptionsDialog
 {
     Q_OBJECT
  private:
  
  public:
     instBatchOptionsDialog(QWidget *parent);
-    virtual void closeEvent(QCloseEvent *e);
-    QString getUName();
-    QString getPWD();
-    QString getEPWD();
 
-
-public slots:
-    virtual void applyChanges();
-    virtual void discardChanges();
-    
- signals:
-/**
- * This signal is emitted from closeEvent, ObjectEditor connects
- * to this signal to make checks before the object editor can be closed
- * and to store its position on the screen
- */
-   // void close_sign(QCloseEvent *e);
     
 };
 
