@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog.cpp,v 1.101 2007/02/16 08:06:28 vkurland Exp $
+  $Id: instDialog.cpp,v 1.102 2007/04/25 05:00:36 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -249,9 +249,7 @@ void instDialog::prepareInstallerOptions(bool fPix)
         f=false;
     }
 
-    dlg->rollback->setEnabled(f);
-    dlg->rollbackTime->setEnabled(f);
-    dlg->rollbackTimeUnit->setEnabled(f);
+    dlg->updateRollback();
     
     QSize pix_options_frame_size = dlg->PIXgroupBox->sizeHint();
 
