@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: instOptionsDialog.cpp,v 1.2 2007/01/06 08:24:57 vkurland Exp $
+  $Id: instOptionsDialog.cpp,v 1.3 2007/04/25 05:00:36 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -37,6 +37,7 @@
 #include <qgroupbox.h>
 #include <qlabel.h>
 #include <qlayout.h>
+#include <qspinbox.h>
 
 #include <stdlib.h>
 
@@ -49,6 +50,8 @@ instOptionsDialog::instOptionsDialog(QWidget *parent) : instOptionsDialog_q(pare
     delta_y = 0;
     setSizeGripEnabled(false);
     resize( 600, 600 );
+
+    updateRollback();
 }
 
 void instOptionsDialog::applyChanges()
@@ -61,6 +64,14 @@ void instOptionsDialog::discardChanges()
     hide();
 }
 
+void instOptionsDialog::updateRollback()
+{
+    bool f = testRun->isChecked();
+    rollback->setEnabled(f);
+    rollbackTime->setEnabled(f);
+    rollbackTimeUnit->setEnabled(f);
+}
+
 QString instOptionsDialog::getUName() { return uname->text(); }
 QString instOptionsDialog::getPWD()   { return pwd->text();   }
 QString instOptionsDialog::getEPWD()  { return epwd->text();  }
