@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: iptAdvancedDialog.cpp,v 1.26 2006/03/16 05:38:14 vkurland Exp $
+  $Id: iptAdvancedDialog.cpp,v 1.28 2007/01/15 04:37:52 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -94,40 +94,43 @@ iptAdvancedDialog::iptAdvancedDialog(QWidget *parent,FWObject *o)
     logLimitSuffix->insertStringList(getScreenNames(slm));
     data.registerOption( logLimitSuffix,   fwoptions,  "limit_suffix", slm); 
     
-    data.registerOption(logLimitVal,          fwoptions, "limit_value"                          );
-    data.registerOption(logAll,               fwoptions, "log_all"                              );
-    data.registerOption(compiler,             fwoptions, "compiler"                             );
-    data.registerOption(compilerArgs,         fwoptions, "cmdline"                              );
-    data.registerOption(outputFileName,       fwoptions, "output_file"                          );
-    data.registerOption(assumeFwIsPartOfAny,  fwoptions, "firewall_is_part_of_any_and_networks" );
-    data.registerOption(acceptSessions,       fwoptions, "accept_new_tcp_with_no_syn"           );
-    data.registerOption(dropInvalid,          fwoptions, "drop_invalid"                         );
-    data.registerOption(logInvalid,           fwoptions, "log_invalid"                          );
-    data.registerOption(acceptESTBeforeFirst, fwoptions, "accept_established"                   );
-    data.registerOption(bridge,               fwoptions, "bridging_fw"                          );
-    data.registerOption(shadowing,            fwoptions, "check_shading"                        );
-    data.registerOption(emptyGroups,          fwoptions, "ignore_empty_groups"                  );
-    data.registerOption(localNAT,             fwoptions, "local_nat"                            );
-    data.registerOption(clampMSStoMTU,        fwoptions, "clamp_mss_to_mtu"                     );
+    data.registerOption(logLimitVal,          fwoptions, "limit_value");
+    data.registerOption(logAll,               fwoptions, "log_all");
+    data.registerOption(compiler,             fwoptions, "compiler");
+    data.registerOption(compilerArgs,         fwoptions, "cmdline");
+    data.registerOption(outputFileName,       fwoptions, "output_file");
+    data.registerOption(assumeFwIsPartOfAny,  fwoptions, "firewall_is_part_of_any_and_networks");
+    data.registerOption(acceptSessions,       fwoptions, "accept_new_tcp_with_no_syn");
+    data.registerOption(dropInvalid,          fwoptions, "drop_invalid");
+    data.registerOption(logInvalid,           fwoptions, "log_invalid");
+    data.registerOption(acceptESTBeforeFirst, fwoptions, "accept_established");
+    data.registerOption(bridge,               fwoptions, "bridging_fw");
+    data.registerOption(shadowing,            fwoptions, "check_shading");
+    data.registerOption(emptyGroups,          fwoptions, "ignore_empty_groups");
+    data.registerOption(localNAT,             fwoptions, "local_nat");
+    data.registerOption(clampMSStoMTU,        fwoptions, "clamp_mss_to_mtu");
+    data.registerOption(makeTagClassifyTerminating,
+                                              fwoptions, "classify_mark_terminating");
 
     slm=getActionsOnReject( obj->getStr("platform").c_str() );
     actionOnReject->clear();
     actionOnReject->insertStringList(getScreenNames(slm));
-    data.registerOption( actionOnReject,   fwoptions,"action_on_reject", slm); 
+    data.registerOption( actionOnReject,      fwoptions,"action_on_reject", slm); 
     
-    data.registerOption(mgmt_ssh    ,fwoptions, "mgmt_ssh"    );
-    data.registerOption(mgmt_addr    ,fwoptions, "mgmt_addr"    );
-    data.registerOption(addVirtualsforNAT    ,fwoptions, "manage_virtual_addr"    );
-    data.registerOption(configureInterfaces    ,fwoptions, "configure_interfaces"    );
-    data.registerOption(iptDebug    ,fwoptions, "debug"    );
-    data.registerOption(verifyInterfaces    ,fwoptions, "verify_interfaces"    );
-    data.registerOption(loadModules    ,fwoptions, "load_modules"    );
-    data.registerOption(iptablesRestoreActivation    ,fwoptions, "use_iptables_restore"    );
-    data.registerOption(ipt_fw_dir    ,fwoptions, "firewall_dir"    );
-    data.registerOption(ipt_user    ,fwoptions, "admUser"    );
-    data.registerOption(altAddress    ,fwoptions, "altAddress"    );
-    data.registerOption(sshArgs    ,fwoptions, "sshArgs"    );
-    data.registerOption(activationCmd    ,fwoptions, "activationCmd"    );
+    data.registerOption(mgmt_ssh,             fwoptions, "mgmt_ssh"    );
+    data.registerOption(mgmt_addr,            fwoptions, "mgmt_addr"    );
+    data.registerOption(addVirtualsforNAT,    fwoptions, "manage_virtual_addr"    );
+    data.registerOption(configureInterfaces,  fwoptions, "configure_interfaces"    );
+    data.registerOption(iptDebug,             fwoptions, "debug"    );
+    data.registerOption(verifyInterfaces,     fwoptions, "verify_interfaces"    );
+    data.registerOption(loadModules,          fwoptions, "load_modules"    );
+    data.registerOption(iptablesRestoreActivation,
+                                              fwoptions, "use_iptables_restore"    );
+    data.registerOption(ipt_fw_dir,           fwoptions, "firewall_dir"    );
+    data.registerOption(ipt_user,             fwoptions, "admUser"    );
+    data.registerOption(altAddress,           fwoptions, "altAddress"    );
+    data.registerOption(sshArgs,              fwoptions, "sshArgs"    );
+    data.registerOption(activationCmd,        fwoptions, "activationCmd"    );
 
 
     PolicyInstallScript *pis   = mgmt->getPolicyInstallScript();
@@ -212,7 +215,8 @@ void iptAdvancedDialog::reject()
 
 void iptAdvancedDialog::editProlog()
 {
-    SimpleTextEditor edt( prolog_script->text(),
+    SimpleTextEditor edt(this,
+                         prolog_script->text(),
                           true, tr( "Script Editor" ) );
     if ( edt.exec() == QDialog::Accepted )
         prolog_script->setText( edt.text() );
@@ -220,7 +224,8 @@ void iptAdvancedDialog::editProlog()
 
 void iptAdvancedDialog::editEpilog()
 {
-    SimpleTextEditor edt( epilog_script->text(),
+    SimpleTextEditor edt(this,
+                         epilog_script->text(),
                           true, tr( "Script Editor" ) );
     if ( edt.exec() == QDialog::Accepted )
         epilog_script->setText( edt.text() );
