@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: pfAdvancedDialog.cpp,v 1.20 2006/09/28 23:36:29 vkurland Exp $
+  $Id: pfAdvancedDialog.cpp,v 1.21 2007/01/06 22:03:25 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -260,7 +260,8 @@ void pfAdvancedDialog::reject()
 
 void pfAdvancedDialog::editProlog()
 {
-    SimpleTextEditor edt( prolog_script->text(),
+    SimpleTextEditor edt(this,
+                         prolog_script->text(),
                           true, tr( "Script Editor" ) );
     if ( edt.exec() == QDialog::Accepted )
         prolog_script->setText( edt.text() );
@@ -268,7 +269,8 @@ void pfAdvancedDialog::editProlog()
 
 void pfAdvancedDialog::editEpilog()
 {
-    SimpleTextEditor edt( epilog_script->text(),
+    SimpleTextEditor edt(this,
+                         epilog_script->text(),
                           true, tr( "Script Editor" ) );
     if ( edt.exec() == QDialog::Accepted )
         epilog_script->setText( edt.text() );
