@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: platforms.cpp,v 1.35 2006/10/24 03:43:25 vkurland Exp $
+  $Id: platforms.cpp,v 1.36 2007/04/14 01:48:51 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -209,8 +209,15 @@ bool isDefaultPolicyRuleOptions(FWOptions *opt)
 		   opt->getInt("limit_burst")<=0         &&
 		   opt->getInt("connlimit_value")<=0     &&
 		   opt->getInt("connlimit_masklen")<=0   &&
+
+		   opt->getStr("hashlimit_name").empty() &&
 		   opt->getInt("hashlimit_value")<=0     &&
 		   opt->getInt("hashlimit_burst")<=0     &&
+		   opt->getInt("hashlimit_size")<=0      &&
+		   opt->getInt("hashlimit_max")<=0       &&
+		   opt->getInt("hashlimit_expire")<=0    &&
+		   opt->getInt("hashlimit_gcinterval")<=0  &&
+
                    opt->getInt("ulog_nlgroup")<=1        &&
                    opt->getStr("limit_suffix").empty()   &&
 		   ! opt->getBool("stateless")           &&
