@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: utils.cpp,v 1.51 2006/10/22 04:39:36 vkurland Exp $
+  $Id: utils.cpp,v 1.53 2007/04/03 15:48:45 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -38,6 +38,7 @@
 #include <qhostaddress.h>
 #include <qapplication.h>
 #include <qpixmapcache.h>
+#include <qdns.h>
 
 #include "fwbuilder/FWObject.h"
 #include "fwbuilder/FWReference.h"
@@ -248,9 +249,16 @@ DWORD  bufCharCount = INFO_BUFFER_SIZE;
     uname=qt_winQString( infoBuf );
     uname=uname.replace(' ','_');
 #else
-    struct passwd *pwd=getpwuid(getuid());
-    assert(pwd);
-    uname=QString(pwd->pw_name);
+
+    char *lname = getenv("LOGNAME");
+    if (lname!=NULL) 
+        uname = QString(lname);
+    else
+    {
+        struct passwd *pwd = getpwuid(getuid());
+        assert(pwd);
+        uname = QString(pwd->pw_name);
+    }
 #endif
     return uname;
 }
