@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: MangleTableCompiler_ipt.cpp,v 1.7 2006/09/09 05:05:00 vkurland Exp $
+  $Id: MangleTableCompiler_ipt.cpp,v 1.8 2007/01/05 06:47:05 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -65,13 +65,27 @@ bool MangleTableCompiler_ipt::keepMangleTableRules::processNext()
     if (rule->getAction() == PolicyRule::Branch &&
         ruleopt->getBool("ipt_branch_in_mangle"))
     {
-        PolicyRule* r = 
-            PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
+        PolicyRule* r;
+
+        // this is a branching rule for mangle table. Need to put it
+        // into PREROUTING and POSTROUTING chains as well because some
+        // targets that work with mangle table can only go into these
+        // chains, yet we do not know what kind of rules will user
+        // place in the branch
+
+        r = PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
         compiler->temp_ruleset->add(r);
         r->duplicate(rule);
         r->setStr("ipt_chain","PREROUTING");
         tmp_queue.push_back(r);
 
+
+        r = PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
+        compiler->temp_ruleset->add(r);
+        r->duplicate(rule);
+        r->setStr("ipt_chain","POSTROUTING");
+        tmp_queue.push_back(r);
+
         tmp_queue.push_back(rule);
     }
 
