@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: OSConfigurator_linux24.cpp,v 1.38 2007/01/16 05:26:54 vkurland Exp $
+  $Id: OSConfigurator_linux24.cpp,v 1.39 2007/04/14 00:57:27 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -614,24 +614,19 @@ void OSConfigurator_linux24::generateCodeForProtocolHandlers(bool have_nat)
     if (options->getBool("load_modules") && !nomod)
     {
 	output << endl;
-	output << "MODULE_DIR=\"/lib/modules/`uname -r`/kernel/net/ipv4/netfilter/\" " << endl;
-/*
- * TODO: make better version comparison
- */
-        string version=fw->getStr("version");
+        output << "MODULES_DIR=\"/lib/modules/`uname -r`/kernel/net/\"" << endl;
+        output << "MODULES=`find $MODULES_DIR -name '*conntrack*'  |  sed -e 's/\\.[^\\.]*$//' -e 's/^.*\\///'`" << endl;
         if (have_nat)
         {
-            output << "MODULES=`(cd $MODULE_DIR; ls *_conntrack* *_nat_* | sed -n -e 's/\\.ko$//p' -e 's/\\.o$//p' -e 's/\\.ko\\.gz$//p' -e 's/\\.o\\.gz$//p')`"
-                   << endl;
-        } else {
-            output << "MODULES=`(cd $MODULE_DIR; ls *_conntrack* | sed -n -e 's/\\.ko$//p' -e 's/\\.o$//p' -e 's/\\.ko\\.gz$//p' -e 's/\\.o\\.gz$//p')`"
-                   << endl;
+            output << "MODULES=\"$MODULES `find $MODULES_DIR -name '*nat*'  |  sed -e 's/\\.[^\\.]*$//' -e 's/^.*\\///'`\"" << endl;
+
         }
 
 	output << "for module in $MODULES; do " << endl;
         output << "  if $LSMOD | grep ${module} >/dev/null; then continue; fi" << endl;
 	output << "  $MODPROBE ${module} ||  exit 1 " << endl;
 	output << "done" << endl;
+
 	output << endl;
 	output << endl;
     }
