@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_PrintRule.cpp,v 1.33 2007/01/15 01:21:58 vkurland Exp $
+  $Id: PolicyCompiler_PrintRule.cpp,v 1.36 2007/04/24 05:59:55 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -221,7 +221,7 @@ string PolicyCompiler_ipt::PrintRule::_printModules(PolicyRule *rule)
 
         ostr << " -m " << module_name << " --" << module_name << " " << lim;
 
-        string ls=ruleopt->getStr("hashlimit_suffix");
+        string ls = ruleopt->getStr("hashlimit_suffix");
         if (!ls.empty()) ostr << ls;
             
         int lb=ruleopt->getInt("hashlimit_burst");
@@ -230,9 +230,27 @@ string PolicyCompiler_ipt::PrintRule::_printModules(PolicyRule *rule)
         ls=ruleopt->getStr("hashlimit_mode");
         if (!ls.empty()) ostr << " --" << module_name << "-mode " << ls;
 
-        std::ostringstream hn;
-        hn << "htable_rule_" << rule->getPosition();
-        ostr << " --" << module_name << "-name " << hn.str();
+        string hl_name = ruleopt->getStr("hashlimit_name");
+        if (hl_name.empty())
+        {
+            std::ostringstream hn;
+            hn << "htable_rule_" << rule->getPosition();
+            hl_name = hn.str();
+        }
+        ostr << " --" << module_name << "-name " << hl_name;
+
+        int arg = ruleopt->getInt("hashlimit_size");
+        if (arg>0) ostr << " --" << module_name << "-htable-size " << arg;
+
+        arg = ruleopt->getInt("hashlimit_max");
+        if (arg>0) ostr << " --" << module_name << "-htable-max " << arg;
+
+        arg = ruleopt->getInt("hashlimit_expire");
+        if (arg>0) ostr << " --" << module_name << "-htable-expire " << arg;
+
+        arg = ruleopt->getInt("hashlimit_gcinterval");
+        if (arg>0) ostr << " --" << module_name << "-htable-gcinterval " << arg;
+
     }
 
     return ostr.str();
@@ -965,34 +983,66 @@ string PolicyCompiler_ipt::PrintRule::_printTimeInterval(PolicyRule *r)
     if (ehour<0) ehour=23;
     if (emin<0)  emin=59;
 
-    ostr << " --timestart "
-         << setw(2) << setfill('0') << shour << ":"
-         << setw(2) << setfill('0') << smin  << " ";
-    ostr << " --timestop "
-         << setw(2) << setfill('0') << ehour << ":"
-         << setw(2) << setfill('0') << emin  << " ";
+    bool use_timestart_timestop = true;
 
-    if (sdayofweek<0) sdayofweek=0;
-    if (sdayofweek>6) sdayofweek=6;
-    if (edayofweek<0) edayofweek=0;
-    if (edayofweek>6) edayofweek=6;
-
-    ostr << " --days ";
-    first=true;
-
-    bool inside_interval = false;
-    int  day=0;
-    while (1)
+    if (sday>0 && smonth>0 && syear>0)
     {
-        if (!inside_interval && day==sdayofweek) inside_interval=true;
-        if (inside_interval)
+        ostr << "--datestart " 
+             << setw(2) << setfill('0') << syear << ":" 
+             << setw(2) << setfill('0') << smonth << ":" 
+             << setw(2) << setfill('0') << sday  << ":"
+             << setw(2) << setfill('0') << shour << ":"
+             << setw(2) << setfill('0') << smin << ":00 ";
+        use_timestart_timestop = false;
+    }
+
+    if (eday>0 && emonth>0 && eyear>0)
+    {
+        ostr << "--datestop "
+             << setw(2) << setfill('0') << syear << ":"
+             << setw(2) << setfill('0') << smonth << ":"
+             << setw(2) << setfill('0') << sday  << ":"
+             << setw(2) << setfill('0') << ehour << ":"
+             << setw(2) << setfill('0') << emin << ":00 ";
+        use_timestart_timestop = false;
+    }
+
+
+    if (use_timestart_timestop )
+    {
+        ostr << " --timestart "
+             << setw(2) << setfill('0') << shour << ":"
+             << setw(2) << setfill('0') << smin  << " ";
+        ostr << " --timestop "
+             << setw(2) << setfill('0') << ehour << ":"
+             << setw(2) << setfill('0') << emin  << " ";
+
+        if (sdayofweek<0) sdayofweek=0;
+        if (sdayofweek>6) sdayofweek=6;
+
+        // if both start and end day are -1, need to
+        // generate "sun,mon,tue,wed,thu,fri,sat"
+        if (edayofweek<0) edayofweek=6;
+        if (edayofweek>6) edayofweek=6;
+
+        ostr << " --days ";
+        first=true;
+
+        bool inside_interval = false;
+        int  day=0;
+        while (1)
         {
-            if (!first) ostr << ",";
-            first=false;
-            ostr << daysofweek[day];
-            if (day==edayofweek)  break;  // if sdayofweek==edayofweek print one day
+            if (!inside_interval && day==sdayofweek) inside_interval=true;
+            if (inside_interval)
+            {
+                if (!first) ostr << ",";
+                first=false;
+                ostr << daysofweek[day];
+                // if sdayofweek==edayofweek print one day
+                if (day==edayofweek)  break;
+            }
+            if (++day>6) day=0;
         }
-        if (++day>6) day=0;
     }
 
     return ostr.str();
