@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipt.h,v 1.27 2007/01/05 06:47:06 vkurland Exp $
+  $Id: PolicyCompiler_ipt.h,v 1.28 2007/04/24 05:52:12 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -311,6 +311,14 @@ namespace fwcompiler {
 	 */
         DECLARE_POLICY_RULE_PROCESSOR(splitIfTagAndConnmark);
 
+        /**
+         * packets that originate on the firewall should be marked in OUTPUT
+         * chain rather than in POSTROUTING because rerouting happens after
+         * OUTPUT hook but before POSTROUTING hook. See diagram at
+         * http://www.shorewall.net/NetfilterOverview.html 
+         */
+        DECLARE_POLICY_RULE_PROCESSOR(TagIfSrcFw);
+            
 	/**
 	 * split rule if Src==any 
 	 * 
