@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipt_optimizer.cpp,v 1.9 2006/09/09 05:05:01 vkurland Exp $
+  $Id: PolicyCompiler_ipt_optimizer.cpp,v 1.10 2006/12/28 06:00:23 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -87,16 +87,18 @@ void PolicyCompiler_ipt::optimize1::optimizeForRuleElement(PolicyRule    *rule,
             } else
             {
                RuleElement *re=RuleElement::cast(rule->getFirstByType((*i)->getTypeName()));
+/* 
+ * put "any tcp" service back in srv field if it was originally some
+ * tcp service. This is needed because we may need to produce
+ * --reject-with tcp-reset if the action is reject and we need to
+ * reject with TCP RST.
+ */
+
                if (RuleElementSrv::isA(re) &&
-                   rule->getAction()==PolicyRule::Reject &&
+                   r->getAction()==PolicyRule::Reject &&
                    ipt_comp->isActionOnRejectTCPRST(r))
                {
                    Service  *srv= compiler->getFirstSrv(r);
-/* need to put "any tcp" service back in srv field if it was
- * originally some tcp service. this is needed because we may need to
- * produce --reject-with tcp-reset if the action is reject and we need
- * to reject with TCP RST
- */
                    if (TCPService::isA(srv))
                    {
                        re->clearChildren();
@@ -119,9 +121,12 @@ void PolicyCompiler_ipt::optimize1::optimizeForRuleElement(PolicyRule    *rule,
     }
     r->setStr("ipt_target",new_chain);
     tmp_queue.push_back(r);
+
     FWOptions *ruleopt=rule->getOptionsObject();
     ruleopt->setBool("stateless",true);
     ruleopt->setInt("limit_value",-1);
+    ruleopt->setInt("connlimit_value",-1);
+    ruleopt->setInt("hashlimit_value",-1);
     rule->setStr("ipt_chain",new_chain);
     rule->setBool("force_state_check",false);
     rule->setStr("upstream_rule_chain",this_chain);
