@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipf_writers.cpp,v 1.9 2006/10/15 23:54:02 vkurland Exp $
+  $Id: PolicyCompiler_ipf_writers.cpp,v 1.10 2007/04/03 16:14:36 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -216,7 +216,7 @@ void PolicyCompiler_ipf::PrintRule::_printWith(libfwbuilder::Service *srv)
 	if ( srv->getBool("fragm") ) 
         {
             if (with) { compiler->output << " with"; with=false; }
-	    compiler->output << " fragm";
+	    compiler->output << " frag";
 	}
 
 	if (srv->getBool("rr")   ) 
@@ -224,6 +224,11 @@ void PolicyCompiler_ipf::PrintRule::_printWith(libfwbuilder::Service *srv)
             if (with) { compiler->output << " with"; with=false; }
             compiler->output << " opt rr";
         }
+	if (srv->getBool("lsrr") ) 
+        {
+            if (with) { compiler->output << " with"; with=false; }
+            compiler->output << " opt lsrr";
+        }
 	if (srv->getBool("ssrr") ) 
         {
             if (with) { compiler->output << " with"; with=false; }
