@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipfw.cpp,v 1.11 2006/09/09 05:05:02 vkurland Exp $
+  $Id: PolicyCompiler_ipfw.cpp,v 1.12 2006/10/07 06:42:44 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -140,6 +140,18 @@ bool PolicyCompiler_ipfw::expandAnyService::processNext()
     return true;
 }
 
+bool PolicyCompiler_ipfw::SpecialRuleActionsForShadowing::processNext()
+{
+    PolicyRule *rule=getNext(); if (rule==NULL) return false;
+
+    if (rule->getAction()==PolicyRule::Pipe ||
+        rule->getAction()==PolicyRule::Custom) 
+        return true;
+
+    tmp_queue.push_back(rule);
+    return true;
+}
+
 bool PolicyCompiler_ipfw::doSrcNegation::processNext()
 {
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
@@ -514,8 +526,9 @@ void PolicyCompiler_ipfw::compile()
         if ( fw->getOptionsObject()->getBool("check_shading")) 
         {
             add( new Begin("Detecting rule shadowing"));
-            add( new printTotalNumberOfRules(                                         ));
+            add( new printTotalNumberOfRules());
 
+            add( new SpecialRuleActionsForShadowing( "disable rules with action Pipe and Custom") );
             add( new ItfNegation(         "process negation in Itf"  ) );
             add( new InterfacePolicyRules("process interface policy rules and store interface ids") );
 
@@ -538,7 +551,7 @@ void PolicyCompiler_ipfw::compile()
                      "expand objects with multiple addresses in DST"));
             add( new ConvertToAtomic("convert to atomic rules"));
             add( new DetectShadowing("Detect shadowing"));
-            add( new simplePrintProgress(                                         ));
+            add( new simplePrintProgress());
 
             runRuleProcessors();
             deleteRuleProcessors();
