@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pf.cpp,v 1.22 2006/05/21 04:47:10 vkurland Exp $
+  $Id: PolicyCompiler_pf.cpp,v 1.25 2006/09/09 05:05:02 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -207,7 +207,7 @@ bool PolicyCompiler_pf::processMultiAddressObjectsInRE::processNext()
 
         for (FWObject::iterator i=maddr_runtime.begin(); i!=maddr_runtime.end(); i++)
         {
-            PolicyRule *r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+            PolicyRule *r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
             compiler->temp_ruleset->add(r);
             r->duplicate(rule);
             nre=RuleElement::cast( r->getFirstByType(re_type) );
@@ -257,7 +257,7 @@ bool PolicyCompiler_pf::splitIfFirewallInSrc::processNext()
 
 	    RuleElementSrc *nsrc;
 
-	    r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME,true) );
+	    r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	    compiler->temp_ruleset->add(r);
 	    r->duplicate(rule);
 	    nsrc=r->getSrc();
@@ -302,7 +302,7 @@ bool PolicyCompiler_pf::splitIfFirewallInDst::processNext()
 
 	    RuleElementDst *ndst;
 
-	    r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME,true) );
+	    r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	    compiler->temp_ruleset->add(r);
 	    r->duplicate(rule);
 	    ndst=r->getDst();
@@ -342,8 +342,9 @@ bool PolicyCompiler_pf::fillDirection::processNext()
     if (rule->getDirectionAsString()=="" || rule->getInterfaceId()=="" )
     {
 	if ( compiler->getCachedFwOpt()->getBool("pass_all_out") )
-            rule->setDirection( PolicyRule::Inbound );
-	else 
+        {
+            if (!rule->isFallback()) rule->setDirection( PolicyRule::Inbound );
+	} else 
         {
 	    rule->setDirection( PolicyRule::Both );
 
@@ -379,7 +380,7 @@ void PolicyCompiler_pf::addDefaultPolicyRule()
          !getCachedFwOpt()->getStr("mgmt_addr").empty() )
     {
 	PolicyRule *r;
-        TCPService *ssh=TCPService::cast(dbcopy->create(TCPService::TYPENAME,false) );
+        TCPService *ssh=TCPService::cast(dbcopy->create(TCPService::TYPENAME) );
         ssh->setInt("dst_range_start",22);
         ssh->setInt("dst_range_end",22);
         ssh->setName("mgmt_ssh");
@@ -416,17 +417,17 @@ void PolicyCompiler_pf::addDefaultPolicyRule()
             abort( errstr );
         }
 
-        Network *mgmt_workstation = Network::cast(dbcopy->create(Network::TYPENAME,false));
+        Network *mgmt_workstation = Network::cast(dbcopy->create(Network::TYPENAME));
         mgmt_workstation->setName("mgmt_addr");
         mgmt_workstation->setAddress( addr );
         mgmt_workstation->setNetmask( netmask );
-//        IPv4 *mgmt_workstation = IPv4::cast(dbcopy->create(IPv4::TYPENAME,false));
+//        IPv4 *mgmt_workstation = IPv4::cast(dbcopy->create(IPv4::TYPENAME));
 //        mgmt_workstation->setAddress( getCachedFwOpt()->getStr("mgmt_addr") );
         dbcopy->add(mgmt_workstation,false);
         cacheObj(mgmt_workstation); // to keep cache consistent
 
 
-	r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME,true) );
+	r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME) );
 	temp_ruleset->add(r);
 	r->setAction(PolicyRule::Accept);
 	r->setLogging(false);
@@ -457,7 +458,7 @@ void PolicyCompiler_pf::addDefaultPolicyRule()
     {
 	PolicyRule *r;
 
-	r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME,true) );
+	r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME) );
 	temp_ruleset->add(r);
 	r->setAction(PolicyRule::Accept);
 	r->setLogging( getCachedFwOpt()->getBool("fallback_log") );
@@ -469,7 +470,7 @@ void PolicyCompiler_pf::addDefaultPolicyRule()
         r->setLabel("fallback rule");
 	combined_ruleset->push_back(r);
 
-	r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME,true) );
+	r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME) );
 	temp_ruleset->add(r);
 	r->setAction(PolicyRule::Deny);
 	r->setLogging( getCachedFwOpt()->getBool("fallback_log") );
@@ -482,7 +483,7 @@ void PolicyCompiler_pf::addDefaultPolicyRule()
 	combined_ruleset->push_back(r);
     } else
     {
-	PolicyRule *r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME,true) );
+	PolicyRule *r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME) );
 	temp_ruleset->add(r);
 	r->setAction(PolicyRule::Deny);
 	r->setLogging( getCachedFwOpt()->getBool("fallback_log") );
@@ -525,14 +526,14 @@ bool PolicyCompiler_pf::SplitDirection::processNext()
 
     if (rule->getDirection()==PolicyRule::Both) {
 	PolicyRule *r= PolicyRule::cast(
-	    compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+	    compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	r->setDirection(PolicyRule::Inbound);
 	tmp_queue.push_back(r);
 
 	r= PolicyRule::cast(
-	    compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+	    compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	r->setDirection(PolicyRule::Outbound);
@@ -563,7 +564,7 @@ bool PolicyCompiler_pf::ProcessScrubOption::processNext()
 	}
 
 	PolicyRule *r= PolicyRule::cast(
-	    compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+	    compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	r->setAction(PolicyRule::Scrub);
@@ -584,7 +585,7 @@ bool PolicyCompiler_pf::ProcessScrubOption::processNext()
 	 ( rule->getAction()==PolicyRule::Deny || rule->getAction()==PolicyRule::Reject) ) {
 
 	PolicyRule *r= PolicyRule::cast(
-	    compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+	    compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	r->setAction(PolicyRule::Scrub);
@@ -623,7 +624,7 @@ bool PolicyCompiler_pf::doSrcNegation::processNext()
         RuleElementSrc *nsrc;
 	PolicyRule     *r;
 
-	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	if (rule->getAction()==PolicyRule::Accept)  r->setAction(PolicyRule::Deny);
@@ -634,7 +635,7 @@ bool PolicyCompiler_pf::doSrcNegation::processNext()
         r->setLogging(false);
 	tmp_queue.push_back(r);
 
-	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
         nsrc=r->getSrc();
@@ -660,7 +661,7 @@ bool PolicyCompiler_pf::doDstNegation::processNext()
         RuleElementDst *ndst;
 	PolicyRule     *r;
 
-	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	if (rule->getAction()==PolicyRule::Accept)  r->setAction(PolicyRule::Deny);
@@ -671,7 +672,7 @@ bool PolicyCompiler_pf::doDstNegation::processNext()
         r->setLogging(false);
 	tmp_queue.push_back(r);
 
-	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
         ndst=r->getDst();
@@ -827,7 +828,7 @@ bool PolicyCompiler_pf::splitIfInterfaceInRE::processNext()
     {
         RuleElement *nre;
 
-        PolicyRule *r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+        PolicyRule *r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
         compiler->temp_ruleset->add(r);
         r->duplicate(rule);
         nre=RuleElement::cast( r->getFirstByType(re_type) );
@@ -835,7 +836,7 @@ bool PolicyCompiler_pf::splitIfInterfaceInRE::processNext()
         for (FWObject::iterator i=cl.begin(); i!=cl.end(); i++) nre->addRef( *i );
         tmp_queue.push_back(r);
 
-        r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+        r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
         compiler->temp_ruleset->add(r);
         r->duplicate(rule);
         nre=RuleElement::cast( r->getFirstByType(re_type) );
@@ -876,7 +877,7 @@ bool PolicyCompiler_pf::separateSrcPort::processNext()
 
             if (srs!=0 || sre!=0) {
                 PolicyRule *r= PolicyRule::cast(
-                    compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+                    compiler->dbcopy->create(PolicyRule::TYPENAME) );
                 compiler->temp_ruleset->add(r);
                 r->duplicate(rule);
                 RuleElementSrv *nsrv=r->getSrv();
@@ -958,6 +959,13 @@ void PolicyCompiler_pf::compile()
             add( new eliminateDuplicatesInSRC("eliminate duplicates in SRC") );
             add( new eliminateDuplicatesInDST("eliminate duplicates in DST") );
             add( new eliminateDuplicatesInSRV("eliminate duplicates in SRV") );
+
+            add( new swapAddressTableObjectsInSrc("AddressTable -> MultiAddressRunTime in Src") );
+            add( new swapAddressTableObjectsInDst("AddressTable -> MultiAddressRunTime in Dst") );
+
+            add( new swapMultiAddressObjectsInSrc("MultiAddress -> MultiAddressRunTime in Src") );
+            add( new swapMultiAddressObjectsInDst("MultiAddress -> MultiAddressRunTime in Dst") );
+
             add( new ExpandMultipleAddressesInSRC("expand objects with multiple addresses in SRC" ) );
             add( new ExpandMultipleAddressesInDST("expand objects with multiple addresses in DST" ) );
             add( new ConvertToAtomic             ("convert to atomic rules") );
