@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pf_writers.cpp,v 1.21 2006/10/15 23:54:02 vkurland Exp $
+  $Id: PolicyCompiler_pf_writers.cpp,v 1.22 2007/03/14 05:22:58 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -718,6 +718,7 @@ bool PolicyCompiler_pf::PrintRule::processNext()
         if (ruleopt->getInt("pf_max_src_conn_rate_num")>0) nopt++;
         if (ruleopt->getStr("pf_max_src_conn_rate_overload_table")!="") nopt++;
 
+        bool not_the_first = false;
         if (nopt)
         {
             if (nopt>1) compiler->output << " ( ";
@@ -725,20 +726,27 @@ bool PolicyCompiler_pf::PrintRule::processNext()
             if (ruleopt->getInt("pf_rule_max_state")>0)
             {
                 compiler->output << " max " << ruleopt->getInt("pf_rule_max_state");
-                if (nopt>1) compiler->output << ",";
-                else        compiler->output << " ";
+                not_the_first = true;
             }
 
             if (ruleopt->getBool("pf_source_tracking"))
             {
+                if (not_the_first) compiler->output << ",";
+
                 compiler->output << " max-src-nodes "
-                                 << ruleopt->getInt("pf_max_src_nodes") << ",";
-                compiler->output << " max-src-states "
-                                 << ruleopt->getInt("pf_max_src_states");
+                                 << ruleopt->getInt("pf_max_src_nodes");
+                if (ruleopt->getInt("pf_max_src_states")>0)
+                {
+                    compiler->output << ", max-src-states "
+                                     << ruleopt->getInt("pf_max_src_states");
+                }
+                not_the_first = true;
             }
 
             if (ruleopt->getInt("pf_max_src_conn")>0)
             {
+                if (not_the_first) compiler->output << ",";
+
                 compiler->output << " max-src-conn "
                                  << ruleopt->getInt("pf_max_src_conn");
                 if (ruleopt->getStr("pf_max_src_conn_overload_table")!="")
@@ -748,11 +756,14 @@ bool PolicyCompiler_pf::PrintRule::processNext()
                     compiler->output << " flush";
                 if (ruleopt->getBool("pf_max_src_conn_global"))
                     compiler->output << " global";
+                not_the_first = true;
             }
 
             if (ruleopt->getInt("pf_max_src_conn_rate_num")>0 && 
                 ruleopt->getInt("pf_max_src_conn_rate_seconds")>0)
             {
+                if (not_the_first) compiler->output << ",";
+
                 compiler->output << " max-src-conn-rate "
                                  << ruleopt->getInt("pf_max_src_conn_rate_num")
                                  << "/"
